//
//  TableViewController.swift
//  Section
//
//  Created by Mark Meretzky on 12/26/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit;

class TableViewController: UITableViewController {
	let cellReuseIdentifier: String = "section";

	let headers: [String] = [	//An array of five Strings.
		"EST: Eastern Standard Time",
		"CST: Central Standard Time",
		"MST: Mountain Standard Time",
		"PST: Pacific Standard Time",
		"\nMiscellaneous"	//The \n (newline) skips a line.
	];
	
	//An array of five arrays (Miyamoto Musashi).
	let zones: [[String]] = [

		//EST: Eastern Standard Time
		[
			"Alabama",
			"Connecticut",
			"Delaware",
			"Florida",
			"Georgia",
			"Indiana",
			"Kentucky",
			"Maine",
			"Maryland",
			"Massachusetts",
			"Michigan",
			"New Hampshire",
			"New Jersey",
			"New York",
			"North Carolina",
			"Ohio",
			"Pennsylvania",
			"Rhode Island",
			"South Carolina",
			"Tennessee",
			"Vermont",
			"Virginia",
			"West Virginia"
		],
	
		//CST: Central Standard Time
		[
			"Arkansas",
			"Illinois",
			"Iowa",
			"Kansas",
			"Louisiana",
			"Minnesota",
			"Mississippi",
			"Missouri",
			"Nebraska",
			"North Dakota",
			"Oklahoma",
			"South Dakota",
			"Texas",
			"Wisconsin"
		],
	
		//MST: Mountain Standard Time
		[
			"Arizona",
			"Colorado",
			"Idaho",
			"Montana",
			"New Mexico",
			"Utah",
			"Wyoming"
		],
	
		//PST: Pacific Standard Time
		[
			"California",
			"Nevada",
			"Oregon",
			"Washington"
		],
	
		//Miscellaneous
		[
			"Alaska",
			"Hawaii"
		]
	];

	//Called from application delegate.

	override init(style: UITableViewStyle) {
		super.init(style: style);
	}

	//Called from the above method.

	override init(nibName: String?, bundle: NSBundle?) {
		super.init(nibName: nibName, bundle: bundle);
	}

	//not called
	required init(coder aDecoder: NSCoder) {
		super.init(nibName: nil, bundle: nil);
	}

	override func viewDidLoad() {
		super.viewDidLoad();
		tableView.registerClass(UITableViewCell.self, forCellReuseIdentifier: cellReuseIdentifier);

		// Uncomment the following line to preserve selection between presentations
		// self.clearsSelectionOnViewWillAppear = false

		// Uncomment the following line to display an Edit button in the navigation bar for this view controller.
		// self.navigationItem.rightBarButtonItem = self.editButtonItem()
	}

	override func didReceiveMemoryWarning() {
		super.didReceiveMemoryWarning();
		// Dispose of any resources that can be recreated.
	}

	// MARK: - Table view data source

	override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
		// Return the number of sections.
		return zones.count;
	}

	override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
		// Return the number of rows in the section.
		assert(0 <= section && section < zones.count);
		return zones[section].count;
	}

	override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
		assert(0 <= indexPath.section && indexPath.section < zones.count
			&& 0 <= indexPath.row && indexPath.row < zones[indexPath.section].count);

		let cell: UITableViewCell =
			tableView.dequeueReusableCellWithIdentifier(cellReuseIdentifier, forIndexPath: indexPath) as UITableViewCell

		// Configure the cell...
		cell.textLabel!.text = zones[indexPath.section][indexPath.row];
		return cell;
	}

	override func tableView(tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
		assert(0 <= section && section < headers.count);
		return headers[section];
	}

	override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
		let cell: UITableViewCell? = tableView.cellForRowAtIndexPath(indexPath);
		if cell != nil {
			if cell!.accessoryType == UITableViewCellAccessoryType.None {
				cell!.accessoryType = UITableViewCellAccessoryType.Checkmark;
			} else {
				cell!.accessoryType = UITableViewCellAccessoryType.None;
			}
		}
	}

	/*
	// Override to support conditional editing of the table view.
	override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
		// Return false if you do not want the specified item to be editable.
		return true;
	}
	*/

	/*
	// Override to support editing the table view.
	override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
		if editingStyle == .Delete {
			// Delete the row from the data source
			tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
		} else if editingStyle == .Insert {
			// Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
		}
	}
	*/

	/*
	// Override to support rearranging the table view.
	override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {
	}
	*/

	/*
	// Override to support conditional rearranging of the table view.
	override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
		// Return false if you do not want the item to be re-orderable.
		return true;
	}
	*/

	/*
	// MARK: - Navigation

	// In a storyboard-based application, you will often want to do a little preparation before navigation
	override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
		// Get the new view controller using [segue destinationViewController].
		// Pass the selected object to the new view controller.
	}
	*/

}
